Kit class
Dart 工具库 - 统一封装常用方法
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
log(
dynamic msg) → void -
Debug 日志输出
MM-DD HH:mm:ss.SSS- 带颜色(Win/VSCode)